@@ -5,6 +5,9 @@ class BaseHTTPResponse:
 
     def __new__(cls, *args, **kwargs):
         message = kwargs.get('message', None) or cls.message or ''
+
+        if message and kwargs.get('message'):
+            del kwargs['message']
         if kwargs.get('pack', False):
             return cls
         if len(args):
